(hfs-delimited path & opts)Creates a tap on HDFS using Cascading's TextDelimited
scheme. Different filesystems can be selected by using different
prefixes for path.
Supports TextDelimited keyword option for :outfields, :classes,
:skip-header?, :delimiter, :write-header?, :strict?,
safe?, and :quote.
Also supports:
:compression - one of :enable, :disable or :default
See cascalog.cascading.tap/hfs-tap for more keyword arguments.
See http://www.cascading.org/javadoc/cascading/tap/Hfs.html and http://www.cascading.org/javadoc/cascading/scheme/TextDelimited.html
Creates a tap on HDFS using Cascading's TextDelimited scheme. Different filesystems can be selected by using different prefixes for `path`. Supports TextDelimited keyword option for `:outfields`, `:classes`, `:skip-header?`, `:delimiter`, `:write-header?`, `:strict?`, `safe?`, and `:quote`. Also supports: `:compression` - one of `:enable`, `:disable` or `:default` See `cascalog.cascading.tap/hfs-tap` for more keyword arguments. See http://www.cascading.org/javadoc/cascading/tap/Hfs.html and http://www.cascading.org/javadoc/cascading/scheme/TextDelimited.html
(hfs-wholefile path & opts)Subquery to return distinct files in the supplied directory. Files
will be returned as 2-tuples, formatted as <filename, file> The
filename is a text object, while the entire, unchopped file is
encoded as a Hadoop BytesWritable object.
Subquery to return distinct files in the supplied directory. Files will be returned as 2-tuples, formatted as `<filename, file>` The filename is a text object, while the entire, unchopped file is encoded as a Hadoop `BytesWritable` object.
(hfs-wrtseqfile path key-type value-type & opts)Creates a tap on HDFS using sequence file format. Different
filesystems can be selected by using different prefixes for path.
Supports keyword option for :outfields. See cascalog.tap/hfs-tap
for more keyword arguments.
See http://www.cascading.org/javadoc/cascading/tap/Hfs.html and http://www.cascading.org/javadoc/cascading/scheme/SequenceFile.html
Creates a tap on HDFS using sequence file format. Different filesystems can be selected by using different prefixes for `path`. Supports keyword option for `:outfields`. See `cascalog.tap/hfs-tap` for more keyword arguments. See http://www.cascading.org/javadoc/cascading/tap/Hfs.html and http://www.cascading.org/javadoc/cascading/scheme/SequenceFile.html
(lfs-delimited path & opts)Creates a tap on the local filesystem using Cascading's
TextDelimited scheme. Different filesystems can be selected by
using different prefixes for path.
Supports TextDelimited keyword option for :outfields, :classes,
:compress?, :skip-header?, :delimiter, :write-header?,
:strict?, safe?, and :quote.
See cascalog.cascading.tap/hfs-tap for more keyword arguments.
See http://www.cascading.org/javadoc/cascading/tap/Hfs.html and http://www.cascading.org/javadoc/cascading/scheme/TextDelimited.html
Creates a tap on the local filesystem using Cascading's TextDelimited scheme. Different filesystems can be selected by using different prefixes for `path`. Supports TextDelimited keyword option for `:outfields`, `:classes`, `:compress?`, `:skip-header?`, `:delimiter`, `:write-header?`, `:strict?`, `safe?`, and `:quote`. See `cascalog.cascading.tap/hfs-tap` for more keyword arguments. See http://www.cascading.org/javadoc/cascading/tap/Hfs.html and http://www.cascading.org/javadoc/cascading/scheme/TextDelimited.html
(lfs-wrtseqfile path key-type value-type & opts)Creates a tap on local file system using sequence file format. Different
filesystems can be selected by using different prefixes for path.
Supports keyword option for :outfields. See cascalog.tap/hfs-tap
for more keyword arguments.
See http://www.cascading.org/javadoc/cascading/tap/Hfs.html and http://www.cascading.org/javadoc/cascading/scheme/SequenceFile.html
Creates a tap on local file system using sequence file format. Different filesystems can be selected by using different prefixes for `path`. Supports keyword option for `:outfields`. See `cascalog.tap/hfs-tap` for more keyword arguments. See http://www.cascading.org/javadoc/cascading/tap/Hfs.html and http://www.cascading.org/javadoc/cascading/scheme/SequenceFile.html
(writable-sequence-file field-names key-type value-type)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |